@@ -1,7 +1,8 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
- * 
+ *
  * Copyright 2000, 2010 Oracle and/or its affiliates.
  *
  * OpenOffice.org - a multi-platform office productivity suite
@@ -56,12 +57,11 @@ namespace dbaccess
     using namespace ::cppu;
     using namespace ::connectivity::sdbcx;
 
-//------------------------------------------------------------------------------
 /** creates a vector of WildCards and reduce the _rTableFilter of the length of WildsCards
 */
 sal_Int32 createWildCardVector(Sequence< ::rtl::OUString >& _rTableFilter, ::std::vector< WildCard >& _rOut)
 {
-    RTL_LOGFILE_CONTEXT_AUTHOR( aLogger, "api", "Ocke.Janssen@sun.com", "OFilteredContainer::createWildCardVector" );	
+    RTL_LOGFILE_CONTEXT_AUTHOR( aLogger, "api", "Ocke.Janssen@sun.com", "OFilteredContainer::createWildCardVector" );
     // for wildcard search : remove all table filters which are a wildcard expression and build a WilCard
     // for them
     ::rtl::OUString* pTableFilters = _rTableFilter.getArray();
@@ -87,7 +87,6 @@ sal_Int32 createWildCardVector(Sequence< ::rtl::OUString >& _rTableFilter, ::std
     return nShiftPos;
 }
 
-    // -------------------------------------------------------------------------
     bool lcl_isElementAllowed(  const ::rtl::OUString& _rName,
                                 const Sequence< ::rtl::OUString >& _rTableFilter,
                                 const ::std::vector< WildCard >& _rWCSearch )
@@ -110,7 +109,6 @@ sal_Int32 createWildCardVector(Sequence< ::rtl::OUString >& _rTableFilter, ::std
         return bFilterMatch;
     }
 
-    //--------------------------------------------------------------------------
     typedef ::boost::optional< ::rtl::OUString >    OptionalString;
     struct TableInfo
     {
@@ -137,7 +135,6 @@ sal_Int32 createWildCardVector(Sequence< ::rtl::OUString >& _rTableFilter, ::std
     };
     typedef ::std::vector< TableInfo >    TableInfos;
 
-    //--------------------------------------------------------------------------
     void lcl_ensureComposedName( TableInfo& _io_tableInfo, const Reference< XDatabaseMetaData >& _metaData )
     {
         if ( !_metaData.is() )
@@ -154,7 +151,6 @@ sal_Int32 createWildCardVector(Sequence< ::rtl::OUString >& _rTableFilter, ::std
         }
     }
 
-    //--------------------------------------------------------------------------
     void lcl_ensureType( TableInfo& _io_tableInfo, const Reference< XDatabaseMetaData >& _metaData, const Reference< XNameAccess >& _masterContainer )
     {
         if ( !!_io_tableInfo.sType )
@@ -178,7 +174,6 @@ sal_Int32 createWildCardVector(Sequence< ::rtl::OUString >& _rTableFilter, ::std
         _io_tableInfo.sType = OptionalString( sTypeName );
     }
 
-    //--------------------------------------------------------------------------
     connectivity::TStringVector lcl_filter( const TableInfos& _unfilteredTables,
         const Sequence< ::rtl::OUString >& _tableFilter, const Sequence< ::rtl::OUString >& _tableTypeFilter,
         const Reference< XDatabaseMetaData >& _metaData, const Reference< XNameAccess >& _masterContainer )
@@ -256,7 +251,7 @@ sal_Int32 createWildCardVector(Sequence< ::rtl::OUString >& _rTableFilter, ::std
     //==========================================================================
     //= OViewContainer
     //==========================================================================
-    OFilteredContainer::OFilteredContainer(::cppu::OWeakObject& _rParent, 
+    OFilteredContainer::OFilteredContainer(::cppu::OWeakObject& _rParent,
                                  ::osl::Mutex& _rMutex,
                                  const Reference< XConnection >& _xCon,
                                  sal_Bool _bCase,
@@ -269,9 +264,9 @@ sal_Int32 createWildCardVector(Sequence< ::rtl::OUString >& _rTableFilter, ::std
         ,m_pRefreshListener(_pRefreshListener)
         ,m_nInAppend(_nInAppend)
         ,m_xConnection(_xCon)
-    {					  
+    {
     }
-    // -------------------------------------------------------------------------
+
     void OFilteredContainer::construct(const Reference< XNameAccess >& _rxMasterContainer,
                                     const Sequence< ::rtl::OUString >& _rTableFilter,
                                     const Sequence< ::rtl::OUString >& _rTableTypeFilter)
@@ -288,7 +283,7 @@ sal_Int32 createWildCardVector(Sequence< ::rtl::OUString >& _rTableFilter, ::std
         }
 
         m_xMasterContainer = _rxMasterContainer;
-        
+
         if ( m_xMasterContainer.is() )
         {
             addMasterContainerListener();
@@ -311,7 +306,7 @@ sal_Int32 createWildCardVector(Sequence< ::rtl::OUString >& _rTableFilter, ::std
             construct( _rTableFilter, _rTableTypeFilter );
         }
     }
-    //------------------------------------------------------------------------------
+
     void OFilteredContainer::construct(const Sequence< ::rtl::OUString >& _rTableFilter, const Sequence< ::rtl::OUString >& _rTableTypeFilter)
     {
         // build sorted versions of the filter sequences, so the visibility decision is faster
@@ -367,7 +362,7 @@ sal_Int32 createWildCardVector(Sequence< ::rtl::OUString >& _rTableFilter, ::std
                 }
             }
 
-            static const ::rtl::OUString sAll = ::rtl::OUString::createFromAscii("%");
+            static const ::rtl::OUString sAll(RTL_CONSTASCII_USTRINGPARAM("%"));
             Reference< XResultSet > xTables = m_xMetaData->getTables( Any(), sAll, sAll, aTableTypeFilter );
             Reference< XRow > xCurrentRow( xTables, UNO_QUERY_THROW );
 
@@ -399,7 +394,6 @@ sal_Int32 createWildCardVector(Sequence< ::rtl::OUString >& _rTableFilter, ::std
         m_bConstructed = sal_True;
     }
 
-    //------------------------------------------------------------------------------
     void OFilteredContainer::disposing()
     {
         OCollection::disposing();
@@ -410,11 +404,10 @@ sal_Int32 createWildCardVector(Sequence< ::rtl::OUString >& _rTableFilter, ::std
         m_xMasterContainer	= NULL;
         m_xMetaData			= NULL;
         m_pWarningsContainer = NULL;
-        m_pRefreshListener	= NULL; 
+        m_pRefreshListener	= NULL;
         m_bConstructed		= sal_False;
     }
 
-    // -------------------------------------------------------------------------
     void OFilteredContainer::impl_refresh() throw(RuntimeException)
     {
         RTL_LOGFILE_CONTEXT_AUTHOR( aLogger, "api", "Ocke.Janssen@sun.com", "OFilteredContainer::impl_refresh" );
@@ -428,14 +421,12 @@ sal_Int32 createWildCardVector(Sequence< ::rtl::OUString >& _rTableFilter, ::std
         }
     }
 
-    // -----------------------------------------------------------------------------
     ::rtl::OUString OFilteredContainer::getNameForObject(const ObjectType& _xObject)
     {
         OSL_ENSURE( _xObject.is(), "OFilteredContainer::getNameForObject: Object is NULL!" );
         return ::dbtools::composeTableName( m_xMetaData, _xObject, ::dbtools::eInDataManipulation, false, false, false );
     }
 
-    // -----------------------------------------------------------------------------
     // multiple to obtain all tables from XDatabaseMetaData::getTables, via passing a particular
     // table type filter:
     // adhere to the standard, which requests to pass a NULL table type filter, if
@@ -491,8 +482,5 @@ sal_Int32 createWildCardVector(Sequence< ::rtl::OUString >& _rTableFilter, ::std
         }
     }
 
-// ..............................................................................
 } // namespace
-// ..............................................................................
-
-
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
