@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -28,84 +29,41 @@
 // MARKER(update_precomp.py): autogen include statement, do not remove
 #include "precompiled_dbaccess.hxx"
 
-#ifndef _COMPHELPER_SEQSTREAM_HXX
-#include <comphelper/seqstream.hxx>
-#endif
-#ifndef _COMPHELPER_UNO3_HXX_
-#include <comphelper/uno3.hxx>
-#endif
-#ifndef _COMPHELPER_EXTRACT_HXX_
-#include <comphelper/extract.hxx>
-#endif
-#ifndef _COM_SUN_STAR_SDBCX_XKEYSSUPPLIER_HPP_
-#include <com/sun/star/sdbcx/XKeysSupplier.hpp>
-#endif
-#ifndef _COM_SUN_STAR_SDBCX_XTABLESSUPPLIER_HPP_
-#include <com/sun/star/sdbcx/XTablesSupplier.hpp>
-#endif
-#ifndef _COM_SUN_STAR_SDBCX_KEYTYPE_HPP_
-#include <com/sun/star/sdbcx/KeyType.hpp>
-#endif
-#ifndef _COM_SUN_STAR_SDBC_RESULTSETCONCURRENCY_HPP_
-#include <com/sun/star/sdbc/ResultSetConcurrency.hpp>
-#endif
-#ifndef _COM_SUN_STAR_SDBC_COLUMNVALUE_HPP_
-#include <com/sun/star/sdbc/ColumnValue.hpp>
-#endif
-#ifndef _COM_SUN_STAR_SDBCX_XCOLUMNSSUPPLIER_HPP_
-#include <com/sun/star/sdbcx/XColumnsSupplier.hpp>
-#endif
-#ifndef _COM_SUN_STAR_SDBCX_PRIVILEGE_HPP_
-#include <com/sun/star/sdbcx/Privilege.hpp>
-#endif
-#ifndef _DBACORE_DATACOLUMN_HXX_
-#include "CRowSetDataColumn.hxx"
-#endif
-#ifndef DBACCESS_CORE_API_CROWSETCOLUMN_HXX
+#include "BookmarkSet.hxx"
 #include "CRowSetColumn.hxx"
-#endif
-#ifndef DBACCESS_CORE_API_ROWSETBASE_HXX
+#include "CRowSetDataColumn.hxx"
+#include "KeySet.hxx"
+#include "OptimisticSet.hxx"
 #include "RowSetBase.hxx"
-#endif
+#include "RowSetCache.hxx"
+#include "StaticSet.hxx"
+#include "WrappedResultSet.hxx"
+#include "core_resource.hrc"
+#include "core_resource.hxx"
+#include "dbastrings.hrc"
+
+#include <com/sun/star/sdbc/ColumnValue.hpp>
+#include <com/sun/star/sdbc/ResultSetConcurrency.hpp>
+#include <com/sun/star/sdbcx/CompareBookmark.hpp>
+#include <com/sun/star/sdbcx/KeyType.hpp>
+#include <com/sun/star/sdbcx/Privilege.hpp>
+#include <com/sun/star/sdbcx/XColumnsSupplier.hpp>
+#include <com/sun/star/sdbcx/XKeysSupplier.hpp>
+#include <com/sun/star/sdbcx/XTablesSupplier.hpp>
+
+#include <comphelper/extract.hxx>
+#include <comphelper/property.hxx>
+#include <comphelper/seqstream.hxx>
+#include <comphelper/uno3.hxx>
 #include <connectivity/dbexception.hxx>
-#include <connectivity/sqlparse.hxx>
-#include <connectivity/sqlnode.hxx>
 #include <connectivity/dbtools.hxx>
 #include <connectivity/sqliterator.hxx>
-#ifndef _COMPHELPER_PROPERTY_HXX_
-#include <comphelper/property.hxx>
-#endif
-#ifndef _COM_SUN_STAR_SDBCX_COMPAREBOOKMARK_HPP_
-#include <com/sun/star/sdbcx/CompareBookmark.hpp>
-#endif
-#ifndef _TOOLS_DEBUG_HXX
+#include <connectivity/sqlnode.hxx>
+#include <connectivity/sqlparse.hxx>
 #include <tools/debug.hxx>
-#endif
+#include <tools/diagnose_ex.h>
 
 #include <algorithm>
-#ifndef DBACCESS_CORE_API_ROWSETCACHE_HXX
-#include "RowSetCache.hxx"
-#endif
-#ifndef _DBA_CORE_RESOURCE_HXX_
-#include "core_resource.hxx"
-#endif
-#ifndef _DBA_CORE_RESOURCE_HRC_
-#include "core_resource.hrc"
-#endif
-#ifndef DBACCESS_CORE_API_BOOKMARKSET_HXX
-#include "BookmarkSet.hxx"
-#endif
-#ifndef DBACCESS_CORE_API_STATICSET_HXX
-#include "StaticSet.hxx"
-#endif
-#ifndef DBACCESS_CORE_API_KEYSET_HXX
-#include "KeySet.hxx"
-#endif
-#ifndef DBACCESS_SHARED_DBASTRINGS_HRC
-#include "dbastrings.hrc"
-#endif
-#include "WrappedResultSet.hxx"
-#include "OptimisticSet.hxx"
 
 using namespace dbaccess;
 using namespace dbtools;
@@ -123,7 +81,7 @@ using namespace ::osl;
 #define CHECK_MATRIX_POS(M) OSL_ENSURE(((M) >= static_cast<ORowSetMatrix::difference_type>(0)) && ((M) < static_cast<sal_Int32>(m_pMatrix->size())),"Position is invalid!")
 
 DBG_NAME(ORowSetCache)
-// -------------------------------------------------------------------------
+
 ORowSetCache::ORowSetCache(const Reference< XResultSet >& _xRs,
                            const Reference< XSingleSelectQueryAnalyzer >& _xAnalyzer,
                            const ::comphelper::ComponentContext& _rContext,
@@ -228,7 +186,10 @@ ORowSetCache::ORowSetCache(const Reference< XResultSet >& _xRs,
                 }
                 catch(const Exception&)
                 {
+                    // DBG_UNHANDLED_EXCEPTION();
                 }
+                m_pCacheSet = NULL;
+                m_xCacheSet.clear();
             }
             else
             {
@@ -386,7 +347,6 @@ ORowSetCache::ORowSetCache(const Reference< XResultSet >& _xRs,
         m_nPrivileges = Privilege::SELECT;
 }
 
-// -------------------------------------------------------------------------
 ORowSetCache::~ORowSetCache()
 {
     m_pCacheSet = NULL;
@@ -409,7 +369,6 @@ ORowSetCache::~ORowSetCache()
     DBG_DTOR(ORowSetCache,NULL);
 }
 
-// -------------------------------------------------------------------------
 void ORowSetCache::setMaxRowSize(sal_Int32 _nSize)
 {
 
@@ -479,14 +438,13 @@ void ORowSetCache::setMaxRowSize(sal_Int32 _nSize)
         m_nEndPos = _nSize;
     }
 }
-// -------------------------------------------------------------------------
 
 // XResultSetMetaDataSupplier
 Reference< XResultSetMetaData > ORowSetCache::getMetaData(  )
 {
     return m_xMetaData;
 }
-// -------------------------------------------------------------------------
+
 Any lcl_getBookmark(ORowSetValue& i_aValue,OCacheSet* i_pCacheSet)
 {
     switch ( i_aValue.getTypeKind() )
@@ -501,7 +459,7 @@ Any lcl_getBookmark(ORowSetValue& i_aValue,OCacheSet* i_pCacheSet)
             return i_aValue.getAny();
     }
 }
-// -------------------------------------------------------------------------
+
 // ::com::sun::star::sdbcx::XRowLocate
 Any ORowSetCache::getBookmark(  )
 {
@@ -509,14 +467,14 @@ Any ORowSetCache::getBookmark(  )
     if(m_bAfterLast)
         throwFunctionSequenceException(m_xSet.get());
 
-    if ( m_aMatrixIter >= m_pMatrix->end() || m_aMatrixIter < m_pMatrix->begin() || !(*m_aMatrixIter).isValid())
+    if ( m_aMatrixIter >= m_pMatrix->end() || m_aMatrixIter < m_pMatrix->begin() || !(*m_aMatrixIter).is())
     {
         return Any(); // this is allowed here because the rowset knowns what it is doing
     }
 
     return lcl_getBookmark(((*m_aMatrixIter)->get())[0],m_pCacheSet);
 }
-// -------------------------------------------------------------------------
+
 sal_Bool ORowSetCache::moveToBookmark( const Any& bookmark )
 {
     if ( m_pCacheSet->moveToBookmark(bookmark) )
@@ -533,7 +491,7 @@ sal_Bool ORowSetCache::moveToBookmark( const Any& bookmark )
             if ( !m_bAfterLast )
             {
                 m_aMatrixIter = calcPosition();
-                OSL_ENSURE(m_aMatrixIter->isValid(),"Iterator after moveToBookmark not valid");
+                OSL_ENSURE(m_aMatrixIter->is(),"Iterator after moveToBookmark not valid");
             }
             else
                 m_aMatrixIter = m_pMatrix->end();
@@ -544,9 +502,9 @@ sal_Bool ORowSetCache::moveToBookmark( const Any& bookmark )
     else
         return sal_False;
 
-    return m_aMatrixIter != m_pMatrix->end() && (*m_aMatrixIter).isValid();
+    return m_aMatrixIter != m_pMatrix->end() && (*m_aMatrixIter).is();
 }
-// -------------------------------------------------------------------------
+
 sal_Bool ORowSetCache::moveRelativeToBookmark( const Any& bookmark, sal_Int32 rows )
 {
     sal_Bool bRet( moveToBookmark( bookmark ) );
@@ -556,28 +514,28 @@ sal_Bool ORowSetCache::moveRelativeToBookmark( const Any& bookmark, sal_Int32 ro
         absolute(m_nPosition);
         //	for(sal_Int32 i=0;i<rows && m_aMatrixIter != m_pMatrix->end();++i,++m_aMatrixIter) ;
 
-        bRet = m_aMatrixIter != m_pMatrix->end() && (*m_aMatrixIter).isValid();
+        bRet = m_aMatrixIter != m_pMatrix->end() && (*m_aMatrixIter).is();
     }
 
     return bRet;
 }
-// -------------------------------------------------------------------------
+
 sal_Int32 ORowSetCache::compareBookmarks( const Any& _first, const Any& _second )
 {
     return (!_first.hasValue() || !_second.hasValue()) ? CompareBookmark::NOT_COMPARABLE : m_pCacheSet->compareBookmarks(_first,_second);
 }
-// -------------------------------------------------------------------------
+
 sal_Bool ORowSetCache::hasOrderedBookmarks(  )
 {
     return m_pCacheSet->hasOrderedBookmarks();
 }
-// -------------------------------------------------------------------------
+
 sal_Int32 ORowSetCache::hashBookmark( const Any& bookmark )
 {
     return m_pCacheSet->hashBookmark(bookmark);
 }
+
 // XRowUpdate
-// -----------------------------------------------------------------------------
 void ORowSetCache::updateNull(sal_Int32 columnIndex,ORowSetValueVector::Vector& io_aRow
                               ,::std::vector<sal_Int32>& o_ChangedColumns
                               )
@@ -593,7 +551,7 @@ void ORowSetCache::updateNull(sal_Int32 columnIndex,ORowSetValueVector::Vector&
     m_pCacheSet->mergeColumnValues(columnIndex,rInsert,io_aRow,o_ChangedColumns);
     impl_updateRowFromCache_throw(io_aRow,o_ChangedColumns);
 }
-// -----------------------------------------------------------------------------
+
 void ORowSetCache::updateValue(sal_Int32 columnIndex,const ORowSetValue& x
                                ,ORowSetValueVector::Vector& io_aRow
                                ,::std::vector<sal_Int32>& o_ChangedColumns
@@ -610,7 +568,7 @@ void ORowSetCache::updateValue(sal_Int32 columnIndex,const ORowSetValue& x
     m_pCacheSet->mergeColumnValues(columnIndex,rInsert,io_aRow,o_ChangedColumns);
     impl_updateRowFromCache_throw(io_aRow,o_ChangedColumns);
 }
-// -------------------------------------------------------------------------
+
 void ORowSetCache::updateCharacterStream( sal_Int32 columnIndex, const Reference< ::com::sun::star::io::XInputStream >& x
                                          , sal_Int32 length,ORowSetValueVector::Vector& io_aRow
                                          ,::std::vector<sal_Int32>& o_ChangedColumns
@@ -631,7 +589,7 @@ void ORowSetCache::updateCharacterStream( sal_Int32 columnIndex, const Reference
     m_pCacheSet->mergeColumnValues(columnIndex,rInsert,io_aRow,o_ChangedColumns);
     impl_updateRowFromCache_throw(io_aRow,o_ChangedColumns);
 }
-// -------------------------------------------------------------------------
+
 void ORowSetCache::updateObject( sal_Int32 columnIndex, const Any& x
                                 ,ORowSetValueVector::Vector& io_aRow
                                 ,::std::vector<sal_Int32>& o_ChangedColumns 
@@ -648,7 +606,7 @@ void ORowSetCache::updateObject( sal_Int32 columnIndex, const Any& x
     m_pCacheSet->mergeColumnValues(columnIndex,rInsert,io_aRow,o_ChangedColumns);
     impl_updateRowFromCache_throw(io_aRow,o_ChangedColumns);
 }
-// -------------------------------------------------------------------------
+
 void ORowSetCache::updateNumericObject( sal_Int32 columnIndex, const Any& x, sal_Int32 /*scale*/
                                        ,ORowSetValueVector::Vector& io_aRow
                                        ,::std::vector<sal_Int32>& o_ChangedColumns
@@ -665,7 +623,7 @@ void ORowSetCache::updateNumericObject( sal_Int32 columnIndex, const Any& x, sal
     m_pCacheSet->mergeColumnValues(columnIndex,rInsert,io_aRow,o_ChangedColumns);
     impl_updateRowFromCache_throw(io_aRow,o_ChangedColumns);
 }
-// -------------------------------------------------------------------------
+
 // XResultSet
 sal_Bool ORowSetCache::next(  )
 {
@@ -688,33 +646,33 @@ sal_Bool ORowSetCache::next(  )
 
     return !m_bAfterLast;
 }
-// -------------------------------------------------------------------------
+
 sal_Bool ORowSetCache::isBeforeFirst(  )
 {
     //	return !m_nPosition;
 
     return m_bBeforeFirst;
 }
-// -------------------------------------------------------------------------
+
 sal_Bool ORowSetCache::isAfterLast(  )
 {
 
     return m_bAfterLast;
 }
-// -------------------------------------------------------------------------
+
 sal_Bool ORowSetCache::isFirst(  )
 {
 
     return m_nPosition == 1; // ask resultset for
 }
-// -------------------------------------------------------------------------
+
 sal_Bool ORowSetCache::isLast(  )
 {
     //	return m_bRowCountFinal ? (m_nPosition==m_nRowCount) : m_pCacheSet->isLast();
 
     return m_nPosition == m_nRowCount;
 }
-// -------------------------------------------------------------------------
+
 sal_Bool ORowSetCache::beforeFirst(  )
 {
 
@@ -730,7 +688,7 @@ sal_Bool ORowSetCache::beforeFirst(  )
     }
     return sal_True;
 }
-// -------------------------------------------------------------------------
+
 sal_Bool ORowSetCache::afterLast(  )
 {
 
@@ -753,7 +711,7 @@ sal_Bool ORowSetCache::afterLast(  )
     }
     return sal_True;
 }
-// -------------------------------------------------------------------------
+
 sal_Bool ORowSetCache::fillMatrix(sal_Int32& _nNewStartPos,sal_Int32 _nNewEndPos)
 {
     OSL_ENSURE(_nNewStartPos != _nNewEndPos,"ORowSetCache::fillMatrix: StartPos and EndPos can not be equal!");
@@ -766,7 +724,7 @@ sal_Bool ORowSetCache::fillMatrix(sal_Int32& _nNewStartPos,sal_Int32 _nNewEndPos
     {
         if(bCheck)
         {
-            if(!aIter->isValid())
+            if(!aIter->is())
                 *aIter = new ORowSetValueVector(m_xMetaData->getColumnCount());
             m_pCacheSet->fillValueRow(*aIter,i);
         }
@@ -793,7 +751,7 @@ sal_Bool ORowSetCache::fillMatrix(sal_Int32& _nNewStartPos,sal_Int32 _nNewEndPos
                 {
                     if(bCheck)
                     {
-                        if(!aIter->isValid())
+                        if(!aIter->is())
                             *aIter = new ORowSetValueVector(m_xMetaData->getColumnCount());
                         m_pCacheSet->fillValueRow(*aIter,nPos++);
                     }
@@ -823,7 +781,7 @@ sal_Bool ORowSetCache::fillMatrix(sal_Int32& _nNewStartPos,sal_Int32 _nNewEndPos
     }
     return bCheck;
 }
-// -------------------------------------------------------------------------
+
 sal_Bool ORowSetCache::moveWindow()
 {
 
@@ -928,7 +886,7 @@ sal_Bool ORowSetCache::moveWindow()
                     bCheck = m_pCacheSet->next();
                     if ( bCheck )
                     {
-                        if(!aIter->isValid())
+                        if(!aIter->is())
                             *aIter = new ORowSetValueVector(m_xMetaData->getColumnCount());
                         m_pCacheSet->fillValueRow(*aIter,i+1);
                     }
@@ -947,7 +905,7 @@ sal_Bool ORowSetCache::moveWindow()
         {	// position in window
             OSL_ENSURE((m_nPosition - m_nStartPos -1) < (sal_Int32)m_pMatrix->size(),"Position is behind end()!");
             m_aMatrixIter = calcPosition();
-            if(!m_aMatrixIter->isValid())
+            if(!m_aMatrixIter->is())
             {
                 sal_Bool bOk( m_pCacheSet->absolute( m_nPosition ) );
                 if ( bOk )
@@ -1033,13 +991,13 @@ sal_Bool ORowSetCache::moveWindow()
                     m_nStartPos = 0;
             }
             // here we need only to check if the begining row is valid. If not we have to fetch it.
-            if(!m_pMatrix->begin()->isValid())
+            if(!m_pMatrix->begin()->is())
             {
                 aIter = m_pMatrix->begin();
 
                 nPos	= m_nStartPos;
                 bCheck	= m_pCacheSet->absolute(m_nStartPos);
-                for(; !aIter->isValid() && bCheck;++aIter)
+                for(; !aIter->is() && bCheck;++aIter)
                 {
                     OSL_ENSURE(aIter != m_pMatrix->end(),"Invalid iterator");
                     bCheck = m_pCacheSet->next();
@@ -1061,7 +1019,7 @@ sal_Bool ORowSetCache::moveWindow()
 
     return bRet;
 }
-// -------------------------------------------------------------------------
+
 sal_Bool ORowSetCache::first(  )
 {
     // first move to the first row
@@ -1086,7 +1044,7 @@ sal_Bool ORowSetCache::first(  )
     }
     return bRet;
 }
-// -------------------------------------------------------------------------
+
 sal_Bool ORowSetCache::last(  )
 {
     sal_Bool bRet = m_pCacheSet->last();
@@ -1102,10 +1060,6 @@ sal_Bool ORowSetCache::last(  )
         moveWindow();
         // we have to repositioning because moveWindow can modify the cache
         m_pCacheSet->last();
-//		if(m_nPosition > m_nFetchSize)
-//			m_aMatrixIter = m_pMatrix->end() -1;
-//		else
-//			m_aMatrixIter = m_pMatrix->begin() + m_nPosition - 1;
         OSL_ENSURE(((m_nPosition - m_nStartPos) - 1) < (sal_Int32)m_pMatrix->size(),"Position is behind end()!");
         m_aMatrixIter = calcPosition();
     }
@@ -1119,18 +1073,18 @@ sal_Bool ORowSetCache::last(  )
 #if OSL_DEBUG_LEVEL > 1
     if(bRet)
     {
-        OSL_ENSURE((*m_aMatrixIter).isValid(),"ORowSetCache::last: Row not valid!");
+        OSL_ENSURE((*m_aMatrixIter).is(),"ORowSetCache::last: Row not valid!");
     }
 #endif
 
     return bRet;
 }
-// -------------------------------------------------------------------------
+
 sal_Int32 ORowSetCache::getRow(  )
 {
     return (isBeforeFirst() || isAfterLast()) ? 0 : m_nPosition;
 }
-// -------------------------------------------------------------------------
+
 sal_Bool ORowSetCache::absolute( sal_Int32 row )
 {
     if(!row )
@@ -1183,7 +1137,7 @@ sal_Bool ORowSetCache::absolute( sal_Int32 row )
 
     return !(m_bAfterLast || m_bBeforeFirst);
 }
-// -------------------------------------------------------------------------
+
 sal_Bool ORowSetCache::relative( sal_Int32 rows )
 {
     sal_Bool bErg = sal_True;
@@ -1211,7 +1165,7 @@ sal_Bool ORowSetCache::relative( sal_Int32 rows )
     }
     return bErg;
 }
-// -------------------------------------------------------------------------
+
 sal_Bool ORowSetCache::previous(  )
 {
     sal_Bool bRet = sal_False;
@@ -1236,13 +1190,13 @@ sal_Bool ORowSetCache::previous(  )
             else
             {
                 m_aMatrixIter = calcPosition();
-                bRet = (*m_aMatrixIter).isValid();
+                bRet = (*m_aMatrixIter).is();
             }
         }
     }
     return bRet;
 }
-// -------------------------------------------------------------------------
+
 void ORowSetCache::refreshRow(  )
 {
     if(isAfterLast())
@@ -1255,21 +1209,21 @@ void ORowSetCache::refreshRow(  )
         cancelRowModification();
     }
 }
-// -------------------------------------------------------------------------
+
 sal_Bool ORowSetCache::rowUpdated(  )
 {
     return m_pCacheSet->rowUpdated();
 }
-// -------------------------------------------------------------------------
+
 sal_Bool ORowSetCache::rowInserted(  )
 {
     return m_pCacheSet->rowInserted();
 }
-// -------------------------------------------------------------------------
+
 // XResultSetUpdate
 sal_Bool ORowSetCache::insertRow(::std::vector< Any >& o_aBookmarks)
 {
-    if ( !m_bNew || !m_aInsertRow->isValid() )
+    if ( !m_bNew || !m_aInsertRow->is() )
         throw SQLException(DBACORE_RESSTRING(RID_STR_NO_MOVETOINSERTROW_CALLED),NULL,SQLSTATE_GENERAL,1000,Any() );
 
     m_pCacheSet->insertRow(*m_aInsertRow,m_aUpdateTable);
@@ -1288,7 +1242,7 @@ sal_Bool ORowSetCache::insertRow(::std::vector< Any >& o_aBookmarks)
             ORowSetMatrix::iterator aIter = m_pMatrix->begin();
             for(;aIter != m_pMatrix->end();++aIter)
             {
-                if ( m_aMatrixIter != aIter && aIter->isValid() && m_pCacheSet->columnValuesUpdated((*aIter)->get(),rCurrentRow) )
+                if ( m_aMatrixIter != aIter && aIter->is() && m_pCacheSet->columnValuesUpdated((*aIter)->get(),rCurrentRow) )
                 {
                     o_aBookmarks.push_back(lcl_getBookmark((*aIter)->get()[0],m_pCacheSet));
                 }
@@ -1301,7 +1255,7 @@ sal_Bool ORowSetCache::insertRow(::std::vector< Any >& o_aBookmarks)
     }
     return bRet;
 }
-// -------------------------------------------------------------------------
+
 void ORowSetCache::resetInsertRow(sal_Bool _bClearInsertRow)
 {
     if ( _bClearInsertRow )
@@ -1309,7 +1263,7 @@ void ORowSetCache::resetInsertRow(sal_Bool _bClearInsertRow)
     m_bNew		= sal_False;
     m_bModified = sal_False;
 }
-// -------------------------------------------------------------------------
+
 void ORowSetCache::cancelRowModification()
 {
     // clear the insertrow references	-> implies that the current row of the rowset changes as well
@@ -1322,7 +1276,7 @@ void ORowSetCache::cancelRowModification()
     } // for(;aCacheIter != aCacheEnd;++aCacheIter)
     resetInsertRow(sal_False);
 }
-// -------------------------------------------------------------------------
+
 void ORowSetCache::updateRow( ORowSetMatrix::iterator& _rUpdateRow,::std::vector< Any >& o_aBookmarks )
 {
     if(isAfterLast() || isBeforeFirst())
@@ -1344,7 +1298,7 @@ void ORowSetCache::updateRow( ORowSetMatrix::iterator& _rUpdateRow,::std::vector
         ORowSetMatrix::iterator aIter = m_pMatrix->begin();
         for(;aIter != m_pMatrix->end();++aIter)
         {
-            if ( m_aMatrixIter != aIter && aIter->isValid() && m_pCacheSet->columnValuesUpdated((*aIter)->get(),rCurrentRow) )
+            if ( m_aMatrixIter != aIter && aIter->is() && m_pCacheSet->columnValuesUpdated((*aIter)->get(),rCurrentRow) )
             {
                 o_aBookmarks.push_back(lcl_getBookmark((*aIter)->get()[0],m_pCacheSet));
             }
@@ -1353,7 +1307,7 @@ void ORowSetCache::updateRow( ORowSetMatrix::iterator& _rUpdateRow,::std::vector
 
     m_bModified = sal_False;
 }
-// -------------------------------------------------------------------------
+
 bool ORowSetCache::deleteRow(  )
 {
     if(isAfterLast() || isBeforeFirst())
@@ -1370,7 +1324,7 @@ bool ORowSetCache::deleteRow(  )
     (*aPos)	  = NULL;
 
     ORowSetMatrix::iterator aEnd = m_pMatrix->end();
-    for(++aPos;aPos != aEnd && aPos->isValid();++aPos)
+    for(++aPos;aPos != aEnd && aPos->is();++aPos)
     {
         *(aPos-1) = *aPos;
         (*aPos)	  = NULL;
@@ -1380,7 +1334,7 @@ bool ORowSetCache::deleteRow(  )
     --m_nPosition;
     return true;
 }
-// -------------------------------------------------------------------------
+
 void ORowSetCache::cancelRowUpdates(  )
 {
     m_bNew = m_bModified = sal_False;
@@ -1398,14 +1352,14 @@ void ORowSetCache::cancelRowUpdates(  )
         ::dbtools::throwFunctionSequenceException(NULL);
     }
 }
-// -------------------------------------------------------------------------
+
 void ORowSetCache::moveToInsertRow(  )
 {
     m_bNew		= sal_True;
     m_bUpdated	= m_bAfterLast = sal_False;
 
     m_aInsertRow = m_pInsertMatrix->begin();
-    if(!m_aInsertRow->isValid())
+    if(!m_aInsertRow->is())
         *m_aInsertRow = new ORowSetValueVector(m_xMetaData->getColumnCount());
 
     // we don't unbound the bookmark column
@@ -1419,7 +1373,7 @@ void ORowSetCache::moveToInsertRow(  )
         aIter->setTypeKind(m_xMetaData->getColumnType(i));
     }
 }
-// -------------------------------------------------------------------------
+
 ORowSetCacheIterator ORowSetCache::createIterator(ORowSetBase* _pRowSet)
 {
 
@@ -1428,7 +1382,7 @@ ORowSetCacheIterator ORowSetCache::createIterator(ORowSetBase* _pRowSet)
     aHelper.pRowSet = _pRowSet;
     return ORowSetCacheIterator(m_aCacheIterators.insert(m_aCacheIterators.begin(),ORowSetCacheMap::value_type(m_aCacheIterators.size()+1,aHelper)),this,_pRowSet);
 }
-// -----------------------------------------------------------------------------
+
 void ORowSetCache::deleteIterator(const ORowSetBase* _pRowSet)
 {
     ORowSetCacheMap::iterator aCacheIter = m_aCacheIterators.begin();
@@ -1443,7 +1397,7 @@ void ORowSetCache::deleteIterator(const ORowSetBase* _pRowSet)
             ++aCacheIter;
     }
 }
-// -----------------------------------------------------------------------------
+
 void ORowSetCache::rotateCacheIterator(ORowSetMatrix::difference_type _nDist)
 {
     if(_nDist)
@@ -1472,11 +1426,11 @@ void ORowSetCache::rotateCacheIterator(ORowSetMatrix::difference_type _nDist)
         }
     }
 }
-// -------------------------------------------------------------------------
+
 void ORowSetCache::setUpdateIterator(const ORowSetMatrix::iterator& _rOriginalRow)
 {
     m_aInsertRow = m_pInsertMatrix->begin();
-    if(!m_aInsertRow->isValid())
+    if(!m_aInsertRow->is())
         *m_aInsertRow = new ORowSetValueVector(m_xMetaData->getColumnCount());
 
     (*(*m_aInsertRow)) = (*(*_rOriginalRow));
@@ -1486,7 +1440,7 @@ void ORowSetCache::setUpdateIterator(const ORowSetMatrix::iterator& _rOriginalRo
     for(;aIter != aEnd;++aIter)
         aIter->setModified(sal_False);
 }
-// -----------------------------------------------------------------------------
+
 void ORowSetCache::checkPositionFlags()
 {
     if(m_bRowCountFinal)
@@ -1496,13 +1450,13 @@ void ORowSetCache::checkPositionFlags()
             m_nPosition = 0;//m_nRowCount;
     }
 }
-// -----------------------------------------------------------------------------
+
 void ORowSetCache::checkUpdateConditions(sal_Int32 columnIndex)
 {
     if(m_bAfterLast || columnIndex >= (sal_Int32)(*m_aInsertRow)->get().size())
         throwFunctionSequenceException(m_xSet.get());
 }
-//------------------------------------------------------------------------------
+
 sal_Bool ORowSetCache::checkInnerJoin(const ::connectivity::OSQLParseNode *pNode,const Reference< XConnection>& _xConnection,const ::rtl::OUString& _sUpdateTableName)
 {
     sal_Bool bOk = sal_False;
@@ -1541,7 +1495,7 @@ sal_Bool ORowSetCache::checkInnerJoin(const ::connectivity::OSQLParseNode *pNode
     }
     return bOk;
 }
-// -----------------------------------------------------------------------------
+
 sal_Bool ORowSetCache::checkJoin(const Reference< XConnection>& _xConnection,
                                  const Reference< XSingleSelectQueryAnalyzer >& _xAnalyzer,
                                  const ::rtl::OUString& _sUpdateTableName )
@@ -1601,11 +1555,11 @@ sal_Bool ORowSetCache::checkJoin(const Reference< XConnection>& _xConnection,
     }
     return bOk;
 }
-// -----------------------------------------------------------------------------
+
 void ORowSetCache::clearInsertRow()
 {
     // we don't unbound the bookmark column
-    if ( m_aInsertRow != m_pInsertMatrix->end() && m_aInsertRow->isValid() )
+    if ( m_aInsertRow != m_pInsertMatrix->end() && m_aInsertRow->is() )
     {
         ORowSetValueVector::Vector::iterator aIter = (*m_aInsertRow)->get().begin()+1;
         ORowSetValueVector::Vector::iterator aEnd = (*m_aInsertRow)->get().end();
@@ -1617,14 +1571,14 @@ void ORowSetCache::clearInsertRow()
         } // for(;aIter != (*m_aInsertRow)->end();++aIter)
     }
 }
-// -----------------------------------------------------------------------------
+
 ORowSetMatrix::iterator	ORowSetCache::calcPosition() const
 {
     sal_Int32 nValue = (m_nPosition - m_nStartPos) - 1;
     CHECK_MATRIX_POS(nValue);
     return ( nValue < 0 || nValue >= static_cast<sal_Int32>(m_pMatrix->size()) ) ? m_pMatrix->end() : (m_pMatrix->begin() + nValue);
 }
-// -----------------------------------------------------------------------------
+
 
 TORowSetOldRowHelperRef ORowSetCache::registerOldRow()
 {
@@ -1632,13 +1586,13 @@ TORowSetOldRowHelperRef ORowSetCache::registerOldRow()
     m_aOldRows.push_back(pRef);
     return pRef;
 }
-// -----------------------------------------------------------------------------
+
 void ORowSetCache::deregisterOldRow(const TORowSetOldRowHelperRef& _rRow)
 {
     TOldRowSetRows::iterator aOldRowEnd = m_aOldRows.end();
     for (TOldRowSetRows::iterator aOldRowIter = m_aOldRows.begin(); aOldRowIter != aOldRowEnd; ++aOldRowIter)
     {
-        if ( aOldRowIter->getBodyPtr() == _rRow.getBodyPtr() )
+        if ( aOldRowIter->get() == _rRow.get() )
         {
             m_aOldRows.erase(aOldRowIter);
             break;
@@ -1646,14 +1600,14 @@ void ORowSetCache::deregisterOldRow(const TORowSetOldRowHelperRef& _rRow)
 
     }
 }
-// -----------------------------------------------------------------------------
+
 sal_Bool ORowSetCache::reFillMatrix(sal_Int32 _nNewStartPos,sal_Int32 _nNewEndPos)
 {
     TOldRowSetRows::iterator aOldRowEnd = m_aOldRows.end();
     for (TOldRowSetRows::iterator aOldRowIter = m_aOldRows.begin(); aOldRowIter != aOldRowEnd; ++aOldRowIter)
     {
-        if ( aOldRowIter->isValid() && aOldRowIter->getBody().getRow().isValid() )
-            aOldRowIter->getBody().setRow(new ORowSetValueVector(aOldRowIter->getBody().getRow().getBody()) );
+        if ( aOldRowIter->is() && (*aOldRowIter)->getRow().is() )
+            (*aOldRowIter)->setRow(new ORowSetValueVector( *((*aOldRowIter)->getRow()) ) );
     }
     sal_Int32 nNewSt = _nNewStartPos;
     sal_Bool bRet = fillMatrix(nNewSt,_nNewEndPos);
@@ -1661,20 +1615,20 @@ sal_Bool ORowSetCache::reFillMatrix(sal_Int32 _nNewStartPos,sal_Int32 _nNewEndPo
     rotateCacheIterator(static_cast<sal_Int16>(m_nFetchSize+1)); // forces that every iterator will be set to null
     return bRet;
 }
-// -----------------------------------------------------------------------------
+
 sal_Bool ORowSetCache::fill(ORowSetMatrix::iterator& _aIter,const ORowSetMatrix::iterator& _aEnd,sal_Int32& _nPos,sal_Bool _bCheck)
 {
     sal_Int32 nColumnCount = m_xMetaData->getColumnCount();
     for(; _bCheck && _aIter != _aEnd;)
     {
-        if ( !_aIter->isValid() )
+        if ( !_aIter->is() )
             *_aIter = new ORowSetValueVector(nColumnCount);
         else
         {
             TOldRowSetRows::iterator aOldRowEnd = m_aOldRows.end();
             for (TOldRowSetRows::iterator aOldRowIter = m_aOldRows.begin(); aOldRowIter != aOldRowEnd; ++aOldRowIter)
             {
-                if ( aOldRowIter->getBody().getRow().isEqualBody(*_aIter) )
+                if ( (*aOldRowIter)->getRow() == *_aIter )
                     *_aIter = new ORowSetValueVector(nColumnCount);
             }
         }
@@ -1683,12 +1637,12 @@ sal_Bool ORowSetCache::fill(ORowSetMatrix::iterator& _aIter,const ORowSetMatrix:
     }
     return _bCheck;
 }
-// -----------------------------------------------------------------------------
+
 bool ORowSetCache::isResultSetChanged() const
 {
     return m_pCacheSet->isResultSetChanged();
 }
-// -----------------------------------------------------------------------------
+
 void ORowSetCache::reset(const Reference< XResultSet>& _xDriverSet)
 {
     m_xMetaData.set(Reference< XResultSetMetaDataSupplier >(_xDriverSet,UNO_QUERY)->getMetaData());
@@ -1698,7 +1652,7 @@ void ORowSetCache::reset(const Reference< XResultSet>& _xDriverSet)
     m_nRowCount = 0;
     reFillMatrix(m_nStartPos+1,m_nEndPos+1);
 }
-// -----------------------------------------------------------------------------
+
 void ORowSetCache::impl_updateRowFromCache_throw(ORowSetValueVector::Vector& io_aRow
                                            ,::std::vector<sal_Int32>& o_ChangedColumns)
 {
@@ -1707,7 +1661,7 @@ void ORowSetCache::impl_updateRowFromCache_throw(ORowSetValueVector::Vector& io_
         ORowSetMatrix::iterator aIter = m_pMatrix->begin();
         for(;aIter != m_pMatrix->end();++aIter)
         {
-            if ( aIter->isValid() && m_pCacheSet->updateColumnValues((*aIter)->get(),io_aRow,o_ChangedColumns))
+            if ( aIter->is() && m_pCacheSet->updateColumnValues((*aIter)->get(),io_aRow,o_ChangedColumns))
             {
                 break;
             }
@@ -1719,4 +1673,4 @@ void ORowSetCache::impl_updateRowFromCache_throw(ORowSetValueVector::Vector& io_
         }
     }
 }
-// -----------------------------------------------------------------------------
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
