@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  * 
@@ -42,7 +43,7 @@
 
 #include <tools/diagnose_ex.h>
 #include <vcl/svapp.hxx>
-#include <vos/mutex.hxx>
+#include <osl/mutex.hxx>
 
 #include <hash_map>
 #include <algorithm>
@@ -463,7 +464,7 @@ namespace dbaui
     //------------------------------------------------------------------------------------------------------------------
     sal_Bool SubComponentManager::closeSubComponents()
     {
-        ::vos::OGuard aSolarGuard( Application::GetSolarMutex() );
+        SolarMutexGuard aSolarGuard;
         ::osl::MutexGuard aGuard( m_pData->getMutex() );
 
         try
@@ -529,7 +530,8 @@ namespace dbaui
     }
 
     //------------------------------------------------------------------------------------------------------------------
-    bool SubComponentManager::activateSubFrame( const ::rtl::OUString& _rName, const sal_Int32 _nComponentType, const ElementOpenMode _eOpenMode ) const
+    bool SubComponentManager::activateSubFrame( const ::rtl::OUString& _rName, const sal_Int32 _nComponentType,
+        const ElementOpenMode _eOpenMode, Reference< XComponent >& o_rComponent ) const
     {
         ::osl::MutexGuard aGuard( m_pData->getMutex() );
 
@@ -546,6 +548,13 @@ namespace dbaui
         const Reference< XTopWindow > xTopWindow( xFrame->getContainerWindow(), UNO_QUERY_THROW );
         xTopWindow->toFront();
 
+        if ( pos->xModel.is() )
+            o_rComponent = pos->xModel.get();
+        else if ( pos->xController.is() )
+            o_rComponent = pos->xController.get();
+        else
+            o_rComponent = pos->xFrame.get();
+
         return true;
     }
 
@@ -602,3 +611,5 @@ namespace dbaui
 //......................................................................................................................
 } // namespace dbaui
 //......................................................................................................................
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
