@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -31,13 +32,9 @@
 #include <com/sun/star/report/ForceNewPage.hpp>
 #include <com/sun/star/beans/PropertyAttribute.hpp>
 #include <com/sun/star/lang/XMultiServiceFactory.hpp>
-#ifndef REPORTDESIGN_SHARED_CORESTRINGS_HRC
 #include "corestrings.hrc"
-#endif
 #include "core_resource.hxx"
-#ifndef REPORTDESIGN_CORE_RESOURCE_HRC_
 #include "core_resource.hrc"
-#endif
 #include <tools/debug.hxx>
 #include "Tools.hxx"
 #include "RptModel.hxx"
@@ -63,7 +60,7 @@ uno::Sequence< ::rtl::OUString> lcl_getGroupAbsent()
                 ,PROPERTY_CANSHRINK
         };
 
-    return uno::Sequence< ::rtl::OUString >(pProps,sizeof(pProps)/sizeof(pProps[0]));
+    return uno::Sequence< ::rtl::OUString >(pProps,SAL_N_ELEMENTS(pProps));
 }
 
 // -----------------------------------------------------------------------------
@@ -104,7 +101,7 @@ uno::Sequence< ::rtl::OUString> lcl_getAbsent(bool _bPageSection)
                 ,PROPERTY_CANSHRINK
                 ,PROPERTY_REPEATSECTION
         };
-        return uno::Sequence< ::rtl::OUString >(pProps,sizeof(pProps)/sizeof(pProps[0]));
+        return uno::Sequence< ::rtl::OUString >(pProps,SAL_N_ELEMENTS(pProps));
     }
 
     ::rtl::OUString pProps[] = {
@@ -113,7 +110,7 @@ uno::Sequence< ::rtl::OUString> lcl_getAbsent(bool _bPageSection)
                 ,PROPERTY_REPEATSECTION
         };
 
-    return uno::Sequence< ::rtl::OUString >(pProps,sizeof(pProps)/sizeof(pProps[0]));
+    return uno::Sequence< ::rtl::OUString >(pProps,SAL_N_ELEMENTS(pProps));
 }
 // -----------------------------------------------------------------------------
 OSection::OSection(const uno::Reference< report::XReportDefinition >& _xParent
@@ -721,3 +718,5 @@ void OSection::notifyElementRemoved(const uno::Reference< drawing::XShape >& xSh
 // =============================================================================
 } // namespace reportdesign
 // =============================================================================
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
