@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -29,28 +30,20 @@
 #include "RptObject.hxx"
 #include "ReportController.hxx"
 #include <cppuhelper/component_context.hxx>
-#ifndef _REPORT_DLGRESID_HRC
 #include <RptResId.hrc>
-#endif
-#ifndef _RPTUI_SLOTID_HRC_
 #include "rptui_slotid.hrc"
-#endif
 #include <tools/debug.hxx>
 #include <com/sun/star/awt/XLayoutConstrains.hpp>
 #include <com/sun/star/inspection/ObjectInspector.hpp>
 #include <com/sun/star/inspection/DefaultHelpProvider.hpp>
-#ifndef _SVX_SVXIDS_HRC
 #include <svx/svxids.hrc>
-#endif
 #include <vcl/stdtext.hxx>
 #include <svx/svdview.hxx>
 #include <svx/svdogrp.hxx>
 #include <svx/svdpage.hxx>
 #include <svx/svditer.hxx>
 
-#ifndef _TOOLKIT_HELPER_VCLUNOHELPER_HXX_
 #include <toolkit/unohlp.hxx>
-#endif
 #include <comphelper/property.hxx>
 #include <comphelper/namecontainer.hxx>
 #include <comphelper/composedprops.hxx>
@@ -64,9 +57,7 @@
 #include <comphelper/processfactory.hxx>
 #include "SectionView.hxx"
 #include "ReportSection.hxx"
-#ifndef REPORTDESIGN_SHARED_UISTRINGS_HRC
 #include "uistrings.hrc"
-#endif
 #include "DesignView.hxx"
 #include "ViewsWindow.hxx"
 #include "UITools.hxx"
@@ -161,7 +152,7 @@ PropBrw::PropBrw(const Reference< XMultiServiceFactory >&	_xORB,Window* pParent,
                 ::cppu::ContextEntry_Init( ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "ActiveConnection" ) ), makeAny( m_pDesignView->getController().getConnection() ) ),
             };
             m_xInspectorContext.set(
-                ::cppu::createComponentContext( aHandlerContextInfo, sizeof( aHandlerContextInfo ) / sizeof( aHandlerContextInfo[0] ),
+                ::cppu::createComponentContext( aHandlerContextInfo, SAL_N_ELEMENTS( aHandlerContextInfo ),
                 xOwnContext ) );
             // create a property browser controller
             bool bEnableHelpSection = lcl_shouldEnableHelpSection( m_xORB );
@@ -232,7 +223,7 @@ PropBrw::~PropBrw()
             const ::rtl::OUString pProps[] = { ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "ContextDocument" ) )
                                             ,  ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "DialogParentWindow" ) )
                                             , ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "ActiveConnection" ) )};
-            for (size_t i = 0; i < sizeof(pProps)/sizeof(pProps[0]); ++i)
+            for (size_t i = 0; i < SAL_N_ELEMENTS(pProps); ++i)
                 xName->removeByName(pProps[i]);
         }
     }
@@ -617,3 +608,5 @@ void PropBrw::LoseFocus()
 }
 //----------------------------------------------------------------------------
 }
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
